@@ -12,13 +12,14 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
 __url__ = "https://github.com/datalad/datalad-installer"
 
 from abc import ABC, abstractmethod
+import ctypes
 from enum import Enum
 from functools import total_ordering
 from getopt import GetoptError, getopt
@@ -518,6 +519,7 @@ class DataladInstaller:
         #: method
         self.installer_stack: List["Installer"] = [
             # Lowest priority first
+            DataladPackagesBuildInstaller(self),
             AutobuildInstaller(self),
             HomebrewInstaller(self),
             NeurodebianInstaller(self),
@@ -559,21 +561,29 @@ class DataladInstaller:
             log.info("Writing environment modifications to %s", fpath)
             self.env_write_files.append(Path(fpath))
 
-    def sudo(self, *args: Any, **kwargs: Any) -> subprocess.CompletedProcess:
+    def sudo(self, *args: Any, **kwargs: Any) -> None:
         arglist = [str(a) for a in args]
         cmd = " ".join(map(shlex.quote, arglist))
-        if self.sudo_confirm is SudoConfirm.ERROR:
-            log.error("Not running sudo command: %s", cmd)
-            sys.exit(1)
-        elif self.sudo_confirm is SudoConfirm.ASK:
-            print("About to run the following sudo command:")
-            print(f"    {cmd}")
-            yan = ask("Proceed?", ["y", "a", "n"])
-            if yan == "n":
-                sys.exit(0)
-            elif yan == "a":
-                self.sudo_confirm = SudoConfirm.OK
-        return runcmd("sudo", *args, **kwargs)
+        if ON_WINDOWS:
+            # The OS will ask the user for confirmation anyway, so there's no
+            # need for us to ask anything.
+            log.info("Running as administrator: %s", " ".join(arglist))
+            ctypes.windll.shell32.ShellExecuteW(  # type: ignore[attr-defined]
+                None, "runas", arglist[0], " ".join(arglist[1:]), None, 1
+            )
+        else:
+            if self.sudo_confirm is SudoConfirm.ERROR:
+                log.error("Not running sudo command: %s", cmd)
+                sys.exit(1)
+            elif self.sudo_confirm is SudoConfirm.ASK:
+                print("About to run the following command as an administrator:")
+                print(f"    {cmd}")
+                yan = ask("Proceed?", ["y", "a", "n"])
+                if yan == "n":
+                    sys.exit(0)
+                elif yan == "a":
+                    self.sudo_confirm = SudoConfirm.OK
+            runcmd("sudo", *args, **kwargs)
 
     @classmethod
     def parse_args(cls, args: List[str]) -> Union[Immediate, ParsedArgs]:
@@ -984,11 +994,57 @@ class NeurodebianComponent(Component):
         ],
     )
 
+    KEY_FINGERPRINT = "0xA5D32F012649A5A9"
+    KEY_URL = "http://neuro.debian.net/_static/neuro.debian.net.asc"
+    DOWNLOAD_SERVER = "us-nh"
+
     def provide(self, extra_args: Optional[List[str]] = None, **kwargs: Any) -> None:
         log.info("Installing & configuring NeuroDebian")
         log.info("Extra args: %s", extra_args)
         if kwargs:
             log.warning("Ignoring extra component arguments: %r", kwargs)
+        r = subprocess.run(
+            ["apt-cache", "show", "neurodebian"],
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
+        )
+        if r.returncode != 0 and "o=NeuroDebian" not in readcmd("apt-cache", "policy"):
+            log.info("NeuroDebian not available in APT and repository not configured")
+            log.info("Configuring NeuroDebian APT repository")
+            release = get_version_codename()
+            log.debug("Detected version codename: %r", release)
+            with tempfile.TemporaryDirectory() as tmpdir:
+                sources_file = os.path.join(tmpdir, "neurodebian.sources.list")
+                download_file(
+                    f"http://neuro.debian.net/lists/{release}.{self.DOWNLOAD_SERVER}.libre",
+                    sources_file,
+                )
+                with open(sources_file) as fp:
+                    log.info(
+                        "Adding the following contents to sources.list.d:\n\n%s",
+                        textwrap.indent(fp.read(), " " * 4),
+                    )
+                self.manager.sudo(
+                    "cp",
+                    "-i",
+                    sources_file,
+                    "/etc/apt/sources.list.d/neurodebian.sources.list",
+                )
+                try:
+                    self.manager.sudo(
+                        "apt-key",
+                        "adv",
+                        "--recv-keys",
+                        "--keyserver",
+                        "hkp://pool.sks-keyservers.net:80",
+                        self.KEY_FINGERPRINT,
+                    )
+                except subprocess.CalledProcessError:
+                    log.info("apt-key command failed; downloading key directly")
+                    keyfile = os.path.join(tmpdir, "neuro.debian.net.asc")
+                    download_file(self.KEY_URL, keyfile)
+                    self.manager.sudo("apt-key", "add", keyfile)
+            self.manager.sudo("apt-get", "update")
         self.manager.sudo(
             "apt-get",
             "install",
@@ -1672,25 +1728,32 @@ class DataladPackagesBuildInstaller(Installer):
         if kwargs:
             log.warning("Ignoring extra installer arguments: %r", kwargs)
         assert package == "git-annex"
-        with tempfile.TemporaryDirectory() as tmpdir_:
-            tmpdir = Path(tmpdir_)
-            if ON_WINDOWS:
-                if version is None:
-                    exefile = "git-annex-installer_latest-snapshot_x64.exe"
-                else:
-                    exefile = f"git-annex-installer_{version}_x64.exe"
-                exepath = tmpdir / exefile
-                download_file(
-                    f"https://datasets.datalad.org/datalad/packages/windows/{exefile}",
-                    exepath,
-                )
-                runcmd(exepath, "/S")
-                binpath = Path("C:/Program Files", "Git", "usr", "bin")
-                self.manager.addpath(binpath)
+        # Installing under a tempfile.TemporaryDirectory() leads to an error
+        # when Python tries to clean up the directory, so we'll just leave the
+        # .exe file alone.
+        tmpdir = mktempdir("dl-datalad-package-")
+        if ON_WINDOWS:
+            if version is None:
+                exefile = "git-annex-installer_latest-snapshot_x64.exe"
             else:
-                raise AssertionError(
-                    "Method should not be called on unsupported platforms"
-                )
+                exefile = f"git-annex-installer_{version}_x64.exe"
+            exepath = tmpdir / exefile
+            download_file(
+                f"https://datasets.datalad.org/datalad/packages/windows/{exefile}",
+                exepath,
+            )
+            try:
+                runcmd(exepath, "/S")
+            except OSError as e:
+                if e.winerror == 740:  # type: ignore[attr-defined]
+                    log.info("Operation requires elevation; rerunning as administrator")
+                    self.manager.sudo(exepath, "/S")
+                else:
+                    raise
+            binpath = Path("C:/Program Files", "Git", "usr", "bin")
+            self.manager.addpath(binpath)
+        else:
+            raise AssertionError("Method should not be called on unsupported platforms")
         log.debug("Installed program directory: %s", binpath)
         return binpath
 
@@ -1783,6 +1846,20 @@ def ask(prompt: str, choices: List[str]) -> str:
             return answer
 
 
+def get_version_codename() -> str:
+    with open("/etc/os-release") as fp:
+        for line in fp:
+            m = re.fullmatch(
+                r'VERSION_CODENAME=(")?(?P<value>[^"]+)(?(1)"|)', line.strip()
+            )
+            if m:
+                return m["value"]
+    # If VERSION_CODENAME is not set in /etc/os-release, then the contents of
+    # /etc/debian_version should be of the form "$VERSION/sid".
+    with open("/etc/debian_version") as fp:
+        return fp.read().partition("/")[0]
+
+
 def main(argv: Optional[List[str]] = None) -> int:
     with DataladInstaller() as manager:
         return manager.main(argv)
