@@ -1,15 +1,16 @@
+import json
 import logging
 from pathlib import Path
-import platform
+import shlex
 import subprocess
 import tempfile
 import pytest
 import datalad_installer
-from datalad_installer import ON_LINUX, main
+from datalad_installer import ON_LINUX, ON_WINDOWS, main
 
 
 def bin_path(binname):
-    if platform.system() == "Windows":
+    if ON_WINDOWS:
         return Path("Scripts", binname + ".exe")
     else:
         return Path("bin", binname)
@@ -69,6 +70,47 @@ def test_install_miniconda_autogen_path(monkeypatch):
     tempfile.tempdir = None  # Reset cache
 
 
+def test_install_env_write_file_miniconda_conda_env(tmp_path):
+    env_write_file = tmp_path / "env.sh"
+    miniconda_path = tmp_path / "conda"
+    r = main(
+        [
+            "datalad_installer.py",
+            "-E",
+            str(env_write_file),
+            "miniconda",
+            "--batch",
+            "--path",
+            str(miniconda_path),
+            "conda-env",
+            "-n",
+            "foo",
+        ]
+    )
+    assert r == 0
+    assert (miniconda_path / bin_path("conda")).exists()
+    assert (miniconda_path / "envs" / "foo").exists()
+    ewf_path = str(env_write_file)
+    if ON_WINDOWS:
+        ewf_path = "/" + ewf_path.replace("\\", "/").replace(":", "", 1)
+        bash = r"C:\Program Files\Git\bin\bash.EXE"
+    else:
+        bash = "bash"
+    r = subprocess.run(
+        [
+            bash,
+            "-c",
+            f"source {shlex.quote(ewf_path)} && conda info --json",
+        ],
+        stdout=subprocess.PIPE,
+        universal_newlines=True,
+        check=True,
+    )
+    info = json.loads(r.stdout)
+    assert info["active_prefix_name"] == "foo"
+    assert info["conda_prefix"] == str(miniconda_path)
+
+
 def test_install_miniconda_datalad(tmp_path):
     miniconda_path = tmp_path / "conda"
     r = main(
@@ -203,17 +245,17 @@ def test_install_miniconda_conda_env_venv_datalad(tmp_path):
     assert not (miniconda_path / "envs" / "foo" / bin_path("datalad")).exists()
 
 
-@pytest.mark.invasive
+@pytest.mark.ci_only
 @pytest.mark.skipif(not ON_LINUX, reason="requires Debian-based system")
 def test_install_neurodebian_sudo_ok(mocker):
     spy = mocker.spy(datalad_installer, "runcmd")
     r = main(["datalad_installer.py", "--sudo=ok", "neurodebian"])
     assert r == 0
-    assert spy.call_args_list == [
-        mocker.call("sudo", "apt-get", "install", "-qy", "neurodebian", env=mocker.ANY),
-        mocker.call("nd-configurerepo"),
-    ]
-    assert spy.call_args_list[0][1]["env"]["DEBIAN_FRONTEND"] == "noninteractive"
+    assert spy.call_args_list[-2] == mocker.call(
+        "sudo", "apt-get", "install", "-qy", "neurodebian", env=mocker.ANY
+    )
+    assert spy.call_args_list[-2][1]["env"]["DEBIAN_FRONTEND"] == "noninteractive"
+    assert spy.call_args_list[-1] == mocker.call("nd-configurerepo")
     r = subprocess.run(
         [
             "dpkg-query",
